# -*- coding: utf-8 -*-

"""Plex module."""

import os
from plexapi.myplex import MyPlexAccount


class HoodexPlexServer(object):
    account = None
    server = None
    token = ""

    def __init__(self, user, password, server):
        self._connect_server(user=user, password=password, server=server)

    def _connect_server(self, user, password, server):
        print("Connecting to plex server {server} with user: {user}...".format(server=server, user=user))

        self.account = MyPlexAccount(user, password)
        self.server = self.account.resource(server).connect()
        self.token = self.account.resource(server).accessToken

    def get_last_added(self, library_name):
        media_list = []
        for media in self.server.library.section(library_name).recentlyAdded():
            local_path = media.locations[0]
            file_name = os.path.basename(local_path)
            media_list.append({
                "file_name": local_path,
                "name": file_name,
                "url": media.media[0].parts[0].key
            })

        return media_list



# -*- coding: utf-8 -*-

"""Main module."""

import configparser
import os
import sys

from hoodex.plex import HoodexPlexServer

PLEX_USER_NAME = ""
PLEX_PASSWORD = ""
PLEX_SERVER = ""
PLEX_LIBRARIES = ""


def run_hoodex_loading_config_file(config_file):
    print("Loading config file: {config}".format(config=config_file))
    if not os.path.isfile(config_file):
        sys.exit("Missing File: Unable to find config file {config_file}".format(config_file=config_file))
    global PLEX_USER_NAME, PLEX_PASSWORD, PLEX_SERVER, PLEX_LIBRARIES
    config = configparser.ConfigParser()
    config.read(filenames=config_file)

    if config.items('hoodex') is None:
        sys.exit(
            "Bad Configuration: Config file {config_file} has missing hoodex section".format(config_file=config_file))
    elif all(keys in ('PlexUserName', 'PlexPassword', 'PlexServer', 'PlexLibraries') for keys in config['hoodex']):
        sys.exit("Bad Configuration: Config file {config_file} has some missing keys".format(config_file=config_file))

    PLEX_USER_NAME = config['hoodex']['PlexUserName']
    PLEX_PASSWORD = config['hoodex']['PlexPassword']
    PLEX_SERVER = config['hoodex']['PlexServer']
    PLEX_LIBRARIES = config['hoodex']['PlexLibraries']


def run_hoodex(plex_user=None, plex_password=None, plex_server=None, plex_libraries=None):
    if plex_user is None:
        plex_user = PLEX_USER_NAME
    if plex_password is None:
        plex_password = PLEX_PASSWORD
    if plex_server is None:
        plex_server = PLEX_SERVER
    if plex_libraries is None:
        plex_libraries = PLEX_LIBRARIES

    plex_server = HoodexPlexServer(user=plex_user, password=plex_password, server=plex_server)

    libraries_dict = {}

    for library in str.split(str(plex_libraries), ','):
        libraries_dict[library] = plex_server.get_last_added(library_name=library)

    print(libraries_dict)

    return libraries_dict



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `main` package."""

import pytest
import os
import hoodex.main as hoodex_main


def test_load_config1_file():
    """Test load config1"""
    config_file = os.path.join("tests", "data", "configs", "config1.ini")
    hoodex_main.run_hoodex_loading_config_file(config_file)
    assert hoodex_main.PLEX_USER_NAME == "user1"
    assert hoodex_main.PLEX_PASSWORD == "password1"
    assert hoodex_main.PLEX_SERVER == "server1"
    assert hoodex_main.PLEX_LIBRARIES == "movies,tv"



# -*- coding: utf-8 -*-

"""Console script for hoodex."""
import sys
import click
from hoodex.main import run_hoodex_loading_config_file, run_hoodex


@click.command()
@click.option('--config', required=False, type=click.STRING, help='Config File.')
@click.option('--user', required=False, type=click.STRING, help='Plex User name.')
@click.option('--password', required=False, type=click.STRING, help='Plex password.')
@click.option('--server', required=False, type=click.STRING, help='Plex server.')
@click.option('--libraries', required=False, type=click.STRING, help='Plex libraries to scan.')
def main(config, user, password, server, libraries):
    """Console script for hoodex."""
    if config:
        run_hoodex_loading_config_file(config)
        run_hoodex()
    else:
        if None in (user, password, server, libraries):
            sys.exit("Missing Argument: you have to set user, password, server and libraries or a config file")
        else:
            run_hoodex(plex_user=user, plex_password=password, plex_server=server, plex_libraries=libraries)

    sys.exit(0)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `cli` package."""

import pytest
import os

from click.testing import CliRunner

from hoodex import cli


def test_command_line_interface_without_parameters():
    """Test the CLI without parameters"""
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 1
    assert "Missing Argument:" in result.exception.args[0]


def test_command_line_interface_help():
    """Test the CLI with --help parameter"""
    runner = CliRunner()
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--config' in help_result.output
    assert '--user' in help_result.output
    assert '--password' in help_result.output
    assert '--server' in help_result.output
    assert '--server' in help_result.output
    assert '--help' in help_result.output


def test_command_line_interface_config_missing_file():
    """Test the CLI with --config parameter"""
    runner = CliRunner()
    config_result = runner.invoke(cli.main, ['--config=missing.ini'])
    assert config_result.exit_code == 1
    assert 'Missing File:' in config_result.output


def test_command_line_interface_config_error():
    """Test the CLI with --config parameter without file"""
    runner = CliRunner()
    config_result = runner.invoke(cli.main, ['--config'])
    assert config_result.exit_code == 2
    assert 'Error: --config option requires an argument' in config_result.output
